# sample_three.py

import wx

"""

https://stackoverflow.com/questions/9136179/what-are-my-options-for-drawing-controls-with-transparent-translucent-background
Author : DanHorner and teuobk

"""

# class TransparentText
# class GradientPanel
# class MyStaticText
# class MyStaticTextWithCustomBackground

#---------------------------------------------------------------------------

class TransparentText(wx.StaticText):
    def __init__(self, parent, id=wx.ID_ANY, label='',
                 pos=wx.DefaultPosition, size=wx.DefaultSize,
                 style=wx.TRANSPARENT_WINDOW, name='transparenttext'):
        wx.StaticText.__init__(self, parent, id, label,
                               pos, size, style, name)

        self.Bind(wx.EVT_PAINT, self.on_paint)
        self.Bind(wx.EVT_ERASE_BACKGROUND, lambda event: None)
        self.Bind(wx.EVT_SIZE, self.on_size)

    #-----------------------------------------------------------------------
        
    def on_paint(self, event):
        bdc = wx.PaintDC(self)
        dc = wx.GCDC(bdc)

        font_face = self.GetFont()
        font_color = self.GetForegroundColour()

        dc.SetFont(font_face)
        dc.SetTextForeground(font_color)
        dc.DrawText(self.GetLabel(), 0, 0)


    def on_size(self, event):
        self.Refresh()
        event.Skip()

#---------------------------------------------------------------------------
        
class GradientPanel(wx.Panel):
    def __init__(self, *args, **kwargs):
        wx.Panel.__init__(self, *args, **kwargs)
        
        self.Bind(wx.EVT_PAINT, lambda e: self.paintBackground())
        self.Bind(wx.EVT_ERASE_BACKGROUND, lambda e: None)

        self.t = wx.StaticText(self,
                               pos=(30, 20),
                               label="wxStaticText. Looks bad on MSW")
        
        self.t2 = MyStaticText(self,
                        pos=(30, 50),
                        size=(300, 25),
                        label="MyStaticText. Needs ClipChildren turned off",
                        style=wx.TRANSPARENT_WINDOW)

        self.t3 = MyStaticTextWithCustomBackground(self,
                        pos=(30, 80),
                        size=(300, 25),
                        label="This Control touches up its own background",
                        paintBackgroundToDC=self.paintBackgroundToDC)
      
        self.t4 = TransparentText(self,
                                  pos=(30, 110),
                                  size=(300, 25),
                                  label="Method TransparentText",
                                  style=wx.TRANSPARENT_WINDOW)

        # Event Handlers
        self.Bind(wx.EVT_SIZE, self.OnSize)

    #-----------------------------------------------------------------------
        
    def OnSize(self, event):
        self.Refresh()
        self.Update()

        
    def paintBackground(self):
        dc = wx.PaintDC(self)
        self.paintBackgroundToDC(self, dc)


    def paintBackgroundToDC(self, ofWindow, dc=None):
        r = self.GetScreenRect()
        r.SetTopLeft(ofWindow.ScreenToClient(r.GetTopLeft()))
        dc.GradientFillLinear(r, wx.Colour(240, 240, 240),
                              wx.Colour(128, 128, 255), wx.SOUTH)

#---------------------------------------------------------------------------
        
class MyStaticText(wx.Window):   # wx.TRANSPARENT_WINDOW
    def __init__(self, parent, label, **kwargs):
        wx.Window.__init__(self, parent, **kwargs)
        
        self.label = label
        
        self.Bind(wx.EVT_PAINT, lambda e: self.repaint())
        self.Bind(wx.EVT_ERASE_BACKGROUND, lambda e: None)

    #-----------------------------------------------------------------------
        
    def repaint(self):
        self.repaintToDC(wx.PaintDC(self))


    def repaintToDC(self,dc):
        dc.DrawText(self.label, 0, 0)

#---------------------------------------------------------------------------
        
class MyStaticTextWithCustomBackground(MyStaticText):
    def __init__(self, parent, label, paintBackgroundToDC=None, **kwargs):
        self.paintBackgroundToDC=paintBackgroundToDC
        MyStaticText.__init__(self, parent, label, **kwargs)

    #-----------------------------------------------------------------------
        
    def repaint(self):
        dc = wx.PaintDC(self)
        if self.paintBackgroundToDC:
            self.paintBackgroundToDC(self, dc)
        MyStaticText.repaintToDC(self, dc)

#---------------------------------------------------------------------------

class MyFrame(wx.Frame):
    def __init__(self):
        style = (wx.DEFAULT_FRAME_STYLE)
        wx.Frame.__init__(self,
                          None,
                          -1,
                          title="",
                          size=(320, 250),
                          style=style)

        #------------

        # Simplified init method.
        self.SetProperties()
        self.CreateCtrls()

    #-----------------------------------------------------------------------

    def SetProperties(self):
        self.SetTitle("Transparent Controls")

        #------------

        frameicon = wx.Icon("Icons/wxWidgets.ico")
        self.SetIcon(frameicon)
        

    def CreateCtrls(self):
        panel = GradientPanel(self)        

#---------------------------------------------------------------------------

class MyApp(wx.App):
    """
    ...
    """
    def OnInit(self):

        #------------

        # wx.SystemOptions.SetOption('msw.window.no-clip-children', 1)
        
        frame = MyFrame()
        self.SetTopWindow(frame)
        frame.Show(True)

        return True

#---------------------------------------------------------------------------

def main():
    app = MyApp(False)
    app.MainLoop()

#---------------------------------------------------------------------------

if __name__ == "__main__" :
    main()


        

